@@ -12,6 +12,7 @@ from m3_gar.models import (
     ApartmentTypes,
     CarplacesParams,
     Houses,
+    Steads,
     HousesParams,
     HouseTypes,
     ParamTypes,
@@ -184,21 +185,13 @@ class AddrObjTypesSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
-class AddrObjSerializer(serializers.ModelSerializer):
+class HierarchicalObjSerializerMixin(
+    metaclass=serializers.SerializerMetaclass
+):
     """
-    Сериализатор сведений классификатора адресообразующих элементов
+    Примесь для сериализаторов объектов содержащих сведения об иерархии.
     """
-    params = AddrObjParamsSerializer(many=True)
     hierarchy = serializers.SerializerMethodField()
-    type_full_name = serializers.SerializerMethodField()
-
-    # На момент описания моделей AddrObjTypes никак не связывается с AddrObj
-    # Существующее поле AddrObj.typename - текстовое представление (ул, пер, г, и т.п.)
-    # ??? = AddrObjTypesSerializer()
-
-    class Meta:
-        model = AddrObj
-        fields = '__all__'
 
     def get_hierarchy(self, obj):
         data = {}
@@ -219,6 +212,25 @@ class AddrObjSerializer(serializers.ModelSerializer):
 
         return data
 
+
+class AddrObjSerializer(
+    HierarchicalObjSerializerMixin,
+    serializers.ModelSerializer
+):
+    """
+    Сериализатор сведений классификатора адресообразующих элементов
+    """
+    params = AddrObjParamsSerializer(many=True)
+    type_full_name = serializers.SerializerMethodField()
+
+    # На момент описания моделей AddrObjTypes никак не связывается с AddrObj
+    # Существующее поле AddrObj.typename - текстовое представление (ул, пер, г, и т.п.)
+    # ??? = AddrObjTypesSerializer()
+
+    class Meta:
+        model = AddrObj
+        fields = '__all__'
+
     def get_type_full_name(self, obj):
         return obj.type_full_name.lower()
 
@@ -241,7 +253,10 @@ class AddhouseTypesSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
-class HousesSerializer(serializers.ModelSerializer):
+class HousesSerializer(
+    HierarchicalObjSerializerMixin,
+    serializers.ModelSerializer
+):
     """
     Сериализатор сведений по номерам домов улиц городов и населенных пунктов
     """
@@ -255,6 +270,21 @@ class HousesSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
+class SteadsSerializer(
+    HierarchicalObjSerializerMixin,
+    serializers.ModelSerializer
+):
+    """
+    Сериализатор сведений по земельным участкам
+    """
+
+    params = SteadsParamsSerializer(many=True)
+
+    class Meta:
+        model = Steads
+        fields = '__all__'
+
+
 class ApartmentTypesSerializer(serializers.ModelSerializer):
     """
     Сериализатор сведений по типам помещений
